@@ -154,14 +154,17 @@ class AstrometryASTAP(object):
 
         tempString = ''
         for line in wcsTextFile:
+            if len(line) > 81:
+                continue
             if line.startswith('END'):
                 continue
             if line.startswith('COMMENT'):
                 continue
+            if line.startswith('CONTINUE'):
+                continue
             tempString += line
 
-        wcsHeader = fits.PrimaryHDU().header.fromstring(tempString,
-                                                        sep='\n')
+        wcsHeader = fits.PrimaryHDU().header.fromstring(tempString, sep='\n')
         return wcsHeader
 
     def solve(self, fitsPath='', raHint=None, decHint=None, scaleHint=None,
@@ -182,7 +185,8 @@ class AstrometryASTAP(object):
         :return: success
         """
         self.process = None
-        self.result = {'success': False}
+        self.result = {'success': False,
+                       'message': 'Internal error'}
 
         if not os.path.isfile(fitsPath):
             self.result['message'] = 'Image missing'
